|***rev.*:**|0.1.13|
|:---|---:|
|***date***:|2025-02-09|

## Introduction

This paper contains a descriptions of all functions presented in "`dtFunc.js`".

### Base functions

<a name="isDateObject"></a>
#### **isDateObject(value)** => `boolean`

This function checks if a given value represents a `DateTime` object and if so returns `true`.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `any` | --- | some element to be verified |

<a name="tryDTValue"></a>
#### **tryDTValue(value) => `object`**

This function tries to read a given value as a time value (*such as timestamp or `DateTime`-object*). As a result the object is returned.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `any` | --- | some element to evaluate |

The result contains two fields:

- `isSucceed` - the flag which marks the function success (*a `boolean` value*);
- `value` - if succeed contains a `DateTime`-instance, if else it is set to `NaN`.

<a name="convValueToTZString"></a>
#### **convValueToTZString(value\[, separator]) => `string`**

This function tries to convert a given value to a string which represent timezone value in `±hhss` format. If failed an empty string returned.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string` | --- | some value |
| `separator` | `string` | --- | \<*reserved*> |

<a name="convTZStringToValue"></a>
#### **convTZStringToValue(value) => `number`**

This function tries to convert a given string which represent timezone value in `±hhmm` format to a number of minutes. If failed `NaN` returned.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `string` | --- | some value |

> NOTE: \[since `v0.0.26`] Formats such as `±hh:mm` and `±hh` are also supported.

<a name="getDateAsString"></a>
#### **getDateAsString(value\[, options]) => `string`**

This function tries to convert a given value to a string which represents time (*e.g. `YYYYMMDD` or `YYYY<sep>MM<sep>DD`*).

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | options |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

\[since: `v0.0.22`] The `options` parameter, if given, must be an object. The following settings supported:

| option name | value type | default value | description |
|:---|---|---:|---|
| `datePartSep` | `string` | `.` | defines a symbol which is used as a date parts separator sing |

> NOTE: For the date parts separator sing the following characters may be used: `.`, `-` and `/`.

<a name="convDTValueToDateString"></a>
#### **convDTValueToDateString(value\[, options]) => `string`**

This function tries to convert a given value to a formated string which represents time.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | options |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

\[since: `v0.0.22`] The `options` parameter, if given, must be an object. The following settings supported:

| option name | value type | default value | description |
|:---|---|---:|---|
| `addDate` | `boolean` | `true` | defines whether a date in the output string must be present |
| `addTime` | `boolean` | `true` | defines whether a time in the output string must be present |
| `addSec` | `boolean` | `true` | when `addTime` is set, defines whether a seconds in the output string must be present |
| `addMSec` | `boolean` | `false` | [since: `v0.0.25`] when `addTime` is set, defines whether a milliseconds in the output string must be present |
| `datePartSep` | `string` | `.` | defines a symbol which is used as a date parts separator sing |
| `msecPartSep` | `string` | `.` | [since: `v0.0.25`] defines a symbol which is used as a separator sing in a time part for milliseconds if applied |

> NOTE:
> - For the date parts separator sing the following characters may be used: `.`, `-` and `/`.
> - For the separator sing in a time part for milliseconds the following characters may be used: `.` and `,`.

<a name="timeLocalToString"></a>
#### **timeLocalToString(value\[, options]) => `string`**

> \[*since: `v0.0.25`*]

This function tries to convert a given value to a formatted string which represents time in format `hh:mm:ss`.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | options |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

The `options` parameter, if given, must be an object. The following settings supported:

| option name | value type | default value | description |
|:---|---|---:|---|
| `addSec` | `boolean` | `true` | when `addTime` is set, defines whether a seconds in the output string must be present |
| `addMSec` | `boolean` | `false` | when `addTime` is set, defines whether a milliseconds in the output string must be present |
| `msecPartSep` | `string` | `.` | defines a symbol which is used as a separator sing in a time part for milliseconds if applied |

> NOTE: For the separator sing in a time part for milliseconds the following characters may be used: `.` and `,`.

<a name="timeUTCToString"></a>
#### **timeUTCToString(value\[, options]) => `string`**

> \[*since: `v0.0.25`*]

This function tries to convert a given value to a formated string which represents time in format `hh:mm:ss`.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | options |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

The `options` parameter, if given, must be an object. The following settings supported:

| option name | value type | default value | description |
|:---|---|---:|---|
| `addSec` | `boolean` | `true` | when `addTime` is set, defines whether a seconds in the output string must be present |
| `addMSec` | `boolean` | `false` | when `addTime` is set, defines whether a milliseconds in the output string must be present |
| `msecPartSep` | `string` | `.` | defines a symbol which is used as a separator sing in a time part for milliseconds if applied |

> NOTE: For the separator sing in a time part for milliseconds the following characters may be used: `.` and `,`.

### Special functions

<a name="trySeparator"></a>
#### **trySeparator(value, list) => `?string`**

> \[*since: `v0.0.26`*]

This function tries to evaluate a given value against a given list of an allowed separators. If failed a `null` returned.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `string` | --- | some value |
| `list` | `string[]` | --- | a list of the allowed separators |

> NOTE:
> - An empty string accepted by this function as a `value` parameter;
> - If a given value match none of the elements in the list, the first element from the list is used as a result value;
> - If a result value is not a string, the function is failed.

### Other functions

<a name="convDTValueToXMLTV"></a>
#### **convDTValueToXMLTV(value\[, options]) => `string`**

This function tries to convert a given value to a string which represents time in an `XMLTV`-format (*e.g. `YYYYMMDDhhmmss ±hhss`*).

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | \<*reserved*> |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

<a name="convXMLTVToDTValue"></a>
#### **convXMLTVToDTValue(value\[, options]) => `null`\|`number`\|`Date`**

This function tries to convert a given string which represent time in an `XMLTV`-format (*e.g. `YYYYMMDDhhmmss ±hhss`*) to a `DateTime`-object. If failed a `null` is returned.

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `string` | --- | some value |
| `options` | `boolean` | --- | a flag to switch a result type |

If an `options` parameter is given and it's set to `true` the function behavior is changed. In such a case the function returned a `timestamp`-value instead of a `DateTime`-object.

<a name="convDTValueToISO8601"></a>
#### **convDTValueToISO8601(value\[, options]) => `string`**

This function tries to convert a given value to a string which represent time in an `ISO8601`-format (*e.g. `YYYY-MM-DD'T'hh:mm:ss ±hh:ss`*).

| parameter name | value type | default value | description |
|:---|---|---:|:---|
| `value` | `number`, `string`, `Date` | --- | some value |
| `options` | `object` | --- | options |

The function accepts a time value (*such as timestamp or `DateTime`-object*). If failed an empty string is returned.

\[since: `v0.0.22`] The `options` parameter, if given, must be an object. The following settings supported:

| option name | value type | default value | description |
|:---|---|---:|---|
| `useBaseFormat` | `boolean` | `false` | defines whether the output string is formatted with accordance to a base format rules of ISO-standard |
| `addDate` | `boolean` | `true` | defines whether a date in the output string must be present |
